@@ -4,7 +4,8 @@ error_message_dict = {
     1000: "连接异常",
     1001: "发送消息异常",
     1002: "当前broker类型不支持",
-    1003: "未找到有效的broker"
+    1003: "未找到有效的broker",
+    1004: "下一步并发，返回结果必须是列表"
 
 }
 
